#!/usr/bin/env python3
# coding: utf-8
# File: chatbot_graph.py
# Author: lhy<lhy_in_blcu@126.com,https://huangyong.github.io>
# Date: 18-10-4

import gradio as gr
from py2neo import Graph
from question_classifier import *
from question_parser import *
from answer_search import *

'''问答类'''


class ChatBotGraph:
    def __init__(self):
        self.g = Graph(
            'http://127.0.0.1:7476',
            user="neo4j",
            password="neo4j")
        self.classifier = QuestionClassifier(self.g)
        self.parser = QuestionPaser()
        self.searcher = AnswerSearcher(self.g)

    def chat_main(self, sent):
        answer = '您好，我是医药智能助理-小益，希望可以帮到您。如果没答上来，可联系人工客服。祝您身体棒棒！'
        res_classify = self.classifier.classify(sent)
        if not res_classify:
            return answer
        res_sql = self.parser.parser_main(res_classify)
        final_answers = self.searcher.search_main(res_sql)
        if not final_answers:
            return answer
        else:
            return '\n'.join(final_answers)


# if __name__ == '__main__':
#     handler = ChatBotGraph()
#     while 1:
#         question = input('用户:')
#         answer = handler.chat_main(question)
#         print('小益:', answer)

with gr.Blocks() as demo:
    gr.close_all()
    handler = ChatBotGraph()
    gr.Markdown(
        """
        # 健康知识问答介绍
        1、左侧输入框输入你想问的问题
        2、点击Submit按钮提交问题，右侧输出框会返回对应的答案
        3、Clear按钮清空输入框
        4、Flag按钮可记录当前的问题和答案，如果测试时对该问答不满意可点击Flag记录，管理员可查看记录
        # 需要做什么？
        1、参考腾讯文档内列举的问题类型，测试能想到的所有其他问法，无法回答的问题整理下来，反馈给李甡
        2、对问题的回答是否满意，不满意整理下来
        腾讯文档：https://docs.qq.com/sheet/DRHRKdkpOZ05yd29Z?tab=BB08J2
        """)
    gr.Interface(
        fn=handler.chat_main,
        inputs="text",
        outputs="text",
    )

if __name__ == '__main__':
    demo.launch(
        share=True,
        server_name="0.0.0.0",
        server_port=7860,
        favicon_path="sources/dcaa038b23790b7dd6ba5569d01d5062.jpeg"
    )
